@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: snap-server
-version: 0.9.2.4
-id: snap-server-0.9.2.4-5c48fe8458d4de1dcdbc6877a2e7b873
+version: 0.9.3.3
+id: snap-server-0.9.3.3-512360e773cc88d02ff8a9ceddc91384
 
 license: BSD3
 copyright:
@@ -34,36 +34,36 @@ hidden-modules: Paths_snap_server Snap.Internal.Http.Parser
                 Snap.Internal.Http.Server.TimeoutManager
                 Snap.Internal.Http.Server.TLS
 trusted: False
-import-dirs: /usr/local/lib/ghc/snap-server-0.9.2.4
-library-dirs: /usr/local/lib/ghc/snap-server-0.9.2.4
-hs-libraries: HSsnap-server-0.9.2.4
+import-dirs: /usr/local/lib/ghc/snap-server-0.9.3.3
+library-dirs: /usr/local/lib/ghc/snap-server-0.9.3.3
+hs-libraries: HSsnap-server-0.9.3.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: MonadCatchIO-transformers-0.3.0.0-76541279080d15c89bf5cb94558aa9e1
-         attoparsec-0.10.1.0-5f1c2093e40bb5451ff760048cacce00
-         attoparsec-enumerator-0.3-1157b0e45bcb851e604a4f659376fa71
-         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         blaze-builder-0.2.1.4-7e5834be78fd9cd5b05f4a14f4001d18
-         blaze-builder-enumerator-0.2.0.4-f7318c0e9f00aac67a8e1aba630ee48e
-         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
-         case-insensitive-0.4.0.1-aede33a6adf1c74693aeb44c801bd09f
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
-         enumerator-0.4.19-27ff248ca60645d7b3b73b44ac567b75
-         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
-         network-2.3.1.0-abef231ef624b7502aa8b0353f2d5ca3
-         old-locale-1.0.0.4-5e45cabd3b4fdcad9e353ea3845f5ef7
-         snap-core-0.9.2.2-f344f1a99fc30d79b2b3b0193c2a6a0e
-         text-0.11.2.3-0a507fb72e97feed1b44644051bc0e5f
-         time-1.4-d61e2caaa0486655b4e141dc277ed49f
-         unix-2.5.1.1-0adea5be633a6b5a124519287d54626d
-         unix-compat-0.3.0.1-b66f7546fa6d25faf14bd9cb263a6d3b
+depends: MonadCatchIO-transformers-0.3.0.0-00f5ba39422294066c7f13d4ef6c89a7
+         attoparsec-0.10.4.0-d9fd97cfc1a1748b3cde35adf7fd233b
+         attoparsec-enumerator-0.3.1-f4fb0a1831d18b63eb3a7ec37a0cda91
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         blaze-builder-0.3.1.1-71a2ae53eb5daf9e6673db8b47b3b6b5
+         blaze-builder-enumerator-0.2.0.5-f74fee72f8b84d91962e5e4025680b57
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         case-insensitive-1.0.0.1-833d4438033d68efab76284bff7688c9
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         enumerator-0.4.19-13fa8f89bd8effdb12c1bcec44c8658a
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+         network-2.4.1.2-3536dbdac401bfea4eb8f7e9e8ce77ed
+         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
+         snap-core-0.9.4.0-143c7f74b4da1dfd50b84e8329b69c2e
+         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
+         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
+         unix-2.6.0.1-eff76fcbf6509b60a4df5e8289027c63
+         unix-compat-0.4.1.1-3ecee737d68c789a8df91c9cd3d2952f
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-snap-server-0.9.2.4/html/snap-server.haddock
-haddock-html: /usr/local/share/doc/hs-snap-server-0.9.2.4/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-snap-server-0.9.3.3/html/snap-server.haddock
+haddock-html: /usr/local/share/doc/hs-snap-server-0.9.3.3/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
